@@ -271,7 +271,10 @@ def parseconfig(args, plugins=()):
                 content = toml_content["tool"]["tox"]["legacy_tox_ini"]
             except KeyError:
                 continue
-        ParseIni(config, config_file, content)
+        try:
+            ParseIni(config, config_file, content)
+        except SkipThisIni:
+            continue
         pm.hook.tox_configure(config=config)  # post process config object
         break
     else:
@@ -282,6 +285,11 @@ def parseconfig(args, plugins=()):
         parser.parse_cli(args, strict=True)
         if option.help or option.helpini:
             return config
+        if option.devenv:
+            # To load defaults, we parse an empty config
+            ParseIni(config, py.path.local(), "")
+            pm.hook.tox_configure(config=config)
+            return config
         msg = "tox config file (either {}) not found"
         candidates = ", ".join(INFO.CONFIG_CANDIDATES)
         feedback(msg.format(candidates), sysexit=not (option.help or option.helpini))
@@ -1045,13 +1053,22 @@ def make_hashseed():
     return str(random.randint(1, max_seed))
 
 
+class SkipThisIni(Exception):
+    """Internal exception to indicate the parsed ini file should be skipped"""
+
+
 class ParseIni(object):
     def __init__(self, config, ini_path, ini_data):  # noqa
         config.toxinipath = ini_path
         using("tox.ini: {} (pid {})".format(config.toxinipath, os.getpid()))
-        config.toxinidir = config.toxinipath.dirpath()
+        config.toxinidir = config.toxinipath.dirpath() if ini_path.check(file=True) else ini_path
 
         self._cfg = py.iniconfig.IniConfig(config.toxinipath, ini_data)
+
+        if ini_path.basename == "setup.cfg" and "tox:tox" not in self._cfg:
+            verbosity1("Found no [tox:tox] section in setup.cfg, skipping.")
+            raise SkipThisIni()
+
         previous_line_of = self._cfg.lineof
 
         self.expand_section_names(self._cfg)
